@@ -1,17 +1,15 @@
-import requests
 import copy
 from datetime import timedelta
-from dateutil.parser import parse as dateutil_parse
-import pytz
 from pyiso.base import BaseClient
 
 
 class ISONEClient(BaseClient):
     def __init__(self):
-        self.ba_name = 'ISONE'
+        self.NAME = 'ISONE'
         
         self.base_url = 'http://isoexpress.iso-ne.com/ws/wsclient'
         self.base_payload = {'_ns0_requestType':'url'}
+        self.TZ_NAME = 'America/New_York'
         
         self.fuels = {
             'Coal': 'coal',
@@ -27,6 +25,10 @@ class ISONEClient(BaseClient):
         }
 
     def get_generation(self, latest=False, start_at=False, end_at=False, **kwargs):
+        # set args
+        self.handle_options(data='gen', latest=latest,
+                            start_at=start_at, end_at=end_at, **kwargs)
+
         # process args
         request_urls = []
         if latest:
@@ -51,19 +53,8 @@ class ISONEClient(BaseClient):
             payload.update({'_ns0_requestUrl':'/genfuelmix/%s' % request_url})
             
             # carry out request
-            try:
-                response = requests.post(self.base_url, data=payload).json()
-            except (ValueError, requests.exceptions.ChunkedEncodingError) as e:
-                # JSON incomplete or not found
-                msg = 'Error in source data for ISONE with payload %s: %s' % (payload, e)
-                self.logger.error(msg)
-                return []
-            except requests.exceptions.ConnectionError as e:
-                # eg max retries exceeded
-                msg = 'Connection error for ISONE with payload %s: %s' % (payload, e)
-                self.logger.error(msg)
-                return []                
-            raw_data += response[0]['data']['GenFuelMixes']['GenFuelMix']
+            response = self.request(self.base_url, mode='post', data=payload)
+            raw_data += response.json()[0]['data']['GenFuelMixes']['GenFuelMix']
 
         # parse data
         for raw_dp in raw_data:
@@ -71,14 +62,14 @@ class ISONEClient(BaseClient):
             parsed_dp = {}
             
             # add values
-            parsed_dp['timestamp'] = dateutil_parse(raw_dp['BeginDate']).astimezone(pytz.utc)
+            parsed_dp['timestamp'] = self.utcify(raw_dp['BeginDate'])
             parsed_dp['gen_MW'] = raw_dp['GenMw']
             parsed_dp['fuel_name'] = self.fuels[raw_dp['FuelCategory']]
-            parsed_dp['ba_name'] = self.ba_name
+            parsed_dp['ba_name'] = self.NAME
             parsed_dp['market'] = self.MARKET_CHOICES.na
             parsed_dp['freq'] = self.FREQUENCY_CHOICES.na
             
             # add to full storage
             parsed_data.append(parsed_dp)
-            
+ 
         return parsed_data
